@@ -1,14 +1,17 @@
 package inc::MakeMaker;
 
 use Moose;
-use Devel::CheckLib;
 
 extends 'Dist::Zilla::Plugin::MakeMaker::Awesome';
 
 override _build_MakeFile_PL_template => sub {
 	my ($self) = @_;
-	my $template  = "use Devel::CheckLib;\n";
-	$template .= "check_lib_or_exit(lib => 'git2');\n";
+
+	my $template  = <<'EOS';
+chdir("xs/libgit2");
+system("make", "-f", "Makefile.embed");
+chdir("../..");
+EOS
 
 	return $template.super();
 };
@@ -16,9 +19,8 @@ override _build_MakeFile_PL_template => sub {
 override _build_WriteMakefile_args => sub {
 	return +{
 		%{ super() },
-		LIBS	=> '-lgit2',
-		INC	=> '-I.',
-		OBJECT	=> '$(O_FILES)',
+		INC	=> '-I. -Ixs/libgit2/include',
+		OBJECT	=> '$(O_FILES) xs/libgit2/libgit2.a',
 	}
 };
 
